@@ -313,6 +313,13 @@ STATUS la_create (HANDLE              lc_handle,
                   SVC_SETUP_CALLBACK  svc_setup_callback,
                   void                (*associate_req_callback)(HANDLE lc_elan_handle,
                                                                 int sizeoftlvs),  /* LANE2 */
+                  void                (*proxy_arp_rsp_callback)(HANDLE lc_elan_handle,
+                                                                UINT8 *mac_addr,
+                                                                UINT32 tran_id,
+                                                                UINT16 lec_id,
+                                                                UINT8 *atm_addr),
+                  void                (*topo_req_xmt_callback)(HANDLE lc_elan_handle,
+                                                               UINT32 flag),
                   HANDLE              *p_la_handle);
 
 /*++
