@@ -7,7 +7,7 @@
 #ifndef _AREQUIPA_H
 #define _AREQUIPA_H
 
-#include <linux/atm.h>
+#include <atm.h>
 
 int arequipa_preset(int sd,const struct sockaddr_atmsvc *addr,
   const struct atm_qos *qos);
