@@ -4,6 +4,7 @@
 #include <errno.h>
 #include <sys/param.h> /* for OPEN_MAX   */
 #include <stdint.h>
+#include <netinet/in.h> /* for ntohl()    */
 #include <linux/atmmpc.h>
 #include <atm.h>
 #include "k_interf.h"
@@ -98,8 +99,8 @@ int msg_from_kernel(int fd)
 		break;               /* not reached */
 	case SND_EGRESS_PURGE:
 	        dprintf("snd_egress_purge,cache_id = %u.\n",msg.content.eg_info.cache_id);
-		send_egress_cache_purge_request(1, /* No reply */
-						msg.content.eg_info.mps_ip,
+		send_egress_cache_purge_request(0, /* 1 == no reply, 0 == reply requested */
+						ntohl(msg.content.eg_info.mps_ip),
 						32,
 						get_own_ip_addr(mpc_control.INTERFACE_NUMBER),
 						msg.content.eg_info.cache_id);
@@ -110,14 +111,18 @@ int msg_from_kernel(int fd)
 		exit(0);
 		break;
 	case OPEN_INGRESS_SVC:
-	        dprintf(" open_ingress_svc");
+	        dprintf(" open_ingress_svc\n");
 		create_ingress_svc(msg.content.in_info.in_dst_ip,
 				   msg.content.in_info.eg_MPC_ATM_addr,
 				   msg.qos);
 		return 1;
 		break;
+        case RELOAD:
+                printf(" reload\n");
+                return 0;
+                break;
         default:
-                dprintf("unknown message %d", msg.type);
+                dprintf("unknown message %d\n", msg.type);
                 return 0;
                 break;               /* not reached */
         }
