@@ -7,11 +7,13 @@
 #define IO_H
 
 #include <stdint.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <linux/atmsvc.h>
 
+#include "proto.h"
 
-#define MAX_ADDRS 128
+
+#define MAX_LOCAL_ADDRS 128
 
 
 typedef struct {
@@ -22,7 +24,6 @@ typedef struct {
 
 
 extern LOCAL_ADDR local_addr[];
-extern struct sockaddr_atmpvc signaling_pvc;
 
 
 int open_all(void);
@@ -32,8 +33,9 @@ void poll_loop(void);
 void close_all(void);
 
 void to_kernel(struct atmsvc_msg *msg);
-void to_net(void *msg,int size);
+void to_net(SIG_ENTITY *sig,void *msg,int size);
 
+struct sockaddr_atmsvc *get_local(int itf);
 int get_addr(int itf);
 
 int get_pvc(int itf,int *vci);
