@@ -1,6 +1,6 @@
 /* proto.h - Common protocol functions and structures */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #ifndef PROTO_H
@@ -78,7 +78,7 @@ typedef struct _socket {
     /* --- UNI information ------------------------------------------------- */
     CALL_STATE call_state;
     unsigned long call_ref; /* bit 24 like when sending */
-    short ep_ref; /* endpoint reference; -1 for p2p */
+    short ep_ref; /* endpoint reference value when sending ; -1 for p2p */
     TIMER *conn_timer; /* current connection timer */
     /* --- some meta-information ------------------------------------------- */
     struct _socket *listen; /* to pending connections, also used for "more" */
