@@ -141,14 +141,17 @@ int sap_encode(Q_DSC *dsc,const struct sockaddr_atmsvc *addr,
 	    q_write(dsc,QF_cdpn_esa,(void *) addr->sas_addr.prv,ATM_ESA_LEN);
 	else return -EDESTADDRREQ;
     if (qos->txtp.traffic_class == ATM_UBR || qos->rxtp.traffic_class ==
-      ATM_UBR) q_assign(dsc,QF_best_effort,0);
-#if defined(UNI40) || defined(DYNAMIC_UNI)
-    if (qos->txtp.traffic_class == ATM_CBR || qos->rxtp.traffic_class ==
-      ATM_CBR) {
-	if (!(uni & S_UNI40)) return -EINVAL;
-	q_assign(dsc,QF_trans_cap,ATM_TC_CBR);
-    }
+      ATM_UBR) {
+	q_assign(dsc,QF_best_effort,0);
+#if defined(UNI30) || defined(ALLOW_UNI30) || defined(DYNAMIC_UNI)
+	if (uni & S_UNI30)
+	    q_assign(dsc,QF_trans_cap,ATM_TC_VBR_NRT_R00);
+	      /* force presence - UNI 3.0 wants this */
 #endif
+    }
+    if (qos->txtp.traffic_class == ATM_CBR || qos->rxtp.traffic_class ==
+      ATM_CBR)
+	q_assign(dsc,QF_trans_cap,ATM_TC_CBR);
     switch (qos->txtp.traffic_class) {
 	case ATM_NONE:
 	    q_assign(dsc,QF_fw_pcr_01,0);
