@@ -1,6 +1,6 @@
 /* uni.c - Processing of incoming UNI signaling messages */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdarg.h>
@@ -754,7 +754,7 @@ static void process_uni(SIG_ENTITY *sig,void *msg)
     }
     if (curr && q_present(&in_dsc,QF_ep_ref) && mid != ATM_MSG_ADD_PARTY &&
       mid != ATM_MSG_DROP_PARTY_ACK)
-	if (curr->ep_ref != q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000) {
+	if (curr->ep_ref != (q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000)) {
 	    send_drop_party_ack(sig,call_ref,
 	      q_fetch(&in_dsc,QF_ep_ref) ^ 0x8000,ATM_CV_INV_EPR);
 	    return;
